@@ -32,7 +32,7 @@ The Django Utils Choices version:
             Female = choices.Choice('f')
             Other = choices.Choice('o')
 
-        gender = models.CharField(max_length=1, choices=Gender.choices)
+        gender = models.CharField(max_length=1, choices=Gender)
 
 To reference these properties:
 
@@ -70,7 +70,7 @@ The Django Utils Choices version:
             Eggs = choices.Choice()
 
         enum = models.IntegerField(
-            choices=Enum.choices, default=Enum.Foo)
+            choices=Enum, default=Enum.Foo)
 
 To reference these properties:
 
@@ -79,12 +79,12 @@ To reference these properties:
     SomeModel.create(enum=SomeModel.Enum.Spam)
 
 '''
-import six
 import collections
 
+import six
+
 
 class ChoicesDict(object):
-
     '''The choices dict is an object that stores a sorted representation of
     the values by key and database value'''
 
@@ -109,12 +109,18 @@ class ChoicesDict(object):
         self._by_value[value.value] = value
 
     def __iter__(self):
-        for k, v in six.iteritems(self._by_value):
-            yield k, v
+        for key, value in six.iteritems(self._by_value):
+            yield key, value
 
     def items(self):
         return list(self)
 
+    def values(self):
+        return list(self._by_key.keys())
+
+    def keys(self):
+        return list(self._by_value.keys())
+
     def __repr__(self):
         return repr(self._by_key)
 
@@ -123,7 +129,6 @@ class ChoicesDict(object):
 
 
 class Choice(object):
-
     '''The choice object has an optional label and value. If the value is not
     given an autoincrementing id (starting from 1) will be used
 
@@ -148,6 +153,12 @@ class Choice(object):
         self.label = label
         self.order = Choice.order
 
+    def __eq__(self, other):
+        if isinstance(other, Choice):  # pragma: no branch
+            return self.value == other.value
+        else:
+            return self.value == other
+
     def __repr__(self):
         repr_ = (six.text_type('<%s[%d]:%s>') % (
             self.__class__.__name__,
@@ -174,9 +185,15 @@ class Choice(object):
         elif six.PY3:
             return six.text_type(label)
 
+    def deconstruct(self):
+        return (
+            '{}.{}'.format(self.__class__.__module__, self.__class__.__name__),
+            (self.value, self.label),
+            {},
+        )
+
 
 class ChoicesMeta(type):
-
     '''The choices metaclass is where all the magic happens, this
     automatically creates a ChoicesDict to get a sorted list of keys and
     values'''
@@ -186,7 +203,7 @@ class ChoicesMeta(type):
         has_values = False
         for key, value in six.iteritems(attrs):
             if isinstance(value, Choice):
-                if value.value:
+                if value.value is not None:
                     has_values = True
 
                 if not value.label:
@@ -198,8 +215,8 @@ class ChoicesMeta(type):
         i = 0
         for key, value in sorted(choices, key=lambda c: c[1].order):
             if has_values:
-                assert value.value, ('Cannot mix choices with and without '
-                                     'values')
+                assert value.value is not None, (
+                    'Cannot mix choices with and without values')
             else:
                 value.value = i
                 i += 1
@@ -209,9 +226,12 @@ class ChoicesMeta(type):
 
         return super(ChoicesMeta, cls).__new__(cls, name, bases, attrs)
 
+    def __iter__(self):
+        for item in self.choices:
+            yield item
+
 
 class Choices(six.with_metaclass(ChoicesMeta)):
-
     '''The choices class is what you should inherit in your Django models
 
     >>> choices = Choices()
@@ -225,17 +245,35 @@ class Choices(six.with_metaclass(ChoicesMeta)):
     'OrderedDict()'
     >>> choices.choices.items()
     []
+    >>> choices.choices.keys()
+    []
+    >>> choices.choices.values()
+    []
+    >>> list(choices)
+    []
 
     >>> class ChoiceTest(Choices):
     ...     a = Choice()
     >>> choices = ChoiceTest()
     >>> choices.choices.items()
-    [(0, <Choice[3]:a>)]
+    [(0, <Choice[...]:a>)]
     >>> choices.a
     0
     >>> choices.choices['a']
-    <Choice[3]:a>
+    <Choice[...]:a>
     >>> choices.choices[0]
-    <Choice[3]:a>
+    <Choice[...]:a>
+    >>> choices.choices.keys()
+    [0]
+    >>> choices.choices.values()
+    ['a']
+    >>> list(choices)
+    [(0, <Choice[...]:a>)]
+    >>> list(ChoiceTest)
+    [(0, <Choice[...]:a>)]
     '''
-    pass
+    choices = ChoicesDict()
+
+    def __iter__(self):
+        for item in self.choices:
+            yield item
